@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Lingy;
-our $VERSION = '0.1.18';
+our $VERSION = '0.1.19';
 
 my $rt = 0;
 
@@ -27,6 +27,14 @@ sub rep {
     return $ret;
 }
 
+sub reps {
+    die "Lingy->rep(string) takes one argument"
+        unless @_ == 2;
+    my ($self, $string) = @_;
+    local $Lingy::Common::error_prefix = $self->error_prefix;
+    return $self->{RT}->rep($string);
+}
+
 sub read {
     die "Lingy->read(string) takes one argument"
         unless @_ == 2;
