@@ -11,6 +11,7 @@ use constant options => +{
     'clj|C'     => 'bool',
     'dev|D'     => 'bool',
     'eval|e'    => 'str',
+    nrepl       => 'bool',
     ppp         => 'bool',
     repl        => 'bool',
     run         => 'arg',
@@ -18,11 +19,12 @@ use constant options => +{
     xxx         => 'bool',
 };
 
+
 sub new {
     my $class = shift;
 
     bless {
-        map( ($_, ''), keys %{$class->options} ),
+        map( ($_, undef), keys %{$class->options} ),
         @_,
     }, $class;
 }
@@ -32,19 +34,21 @@ sub run {
 
     $self->getopt(@args);
 
-    my ($repl, $run, $eval, $version, $clj, $dev, $args) =
-        @{$self}{qw<repl run eval version clj dev args>};
+    my ($repl, $run, $eval, $version, $clj, $dev, $nrepl, $args) =
+        @{$self}{qw<repl run eval version clj dev nrepl args>};
     local @ARGV = @$args;
 
+    return $self->do_nrepl if $nrepl;
+
     RT->init;
     RT->rep(qq<(clojure-repl-on)>) if $clj;
     RT->rep(qq<(use 'lingy.devel)>) if $dev;
 
-    $version ? $self->do_version() :
-    $eval ? $self->do_eval() :
-    $repl ? $self->do_repl() :
-    $run ? $self->do_run() :
-    $self->do_repl();
+    $version ? $self->do_version :
+    $eval ? $self->do_eval :
+    $repl ? $self->do_repl :
+    $run ? $self->do_run :
+    $self->do_repl;
 }
 
 sub do_version {
@@ -75,6 +79,12 @@ sub do_eval {
     }
 }
 
+sub do_nrepl {
+    my ($self) = @_;
+    require Lingy::nREPL;
+    Lingy::nREPL->new->start->run;
+}
+
 sub do_repl {
     RT->repl;
 }
@@ -145,7 +155,6 @@ sub getopt {
             $self->{run} = '/dev/stdin'
                 if $self->{run} eq '-';
         }
-
     } else {
         if ($self->from_stdin) {
             $self->{run} = '/dev/stdin';
